#
# spec file for package python-cogapp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-cogapp
Version:        3.3.0
Release:        2.3
Summary:        A code generator for executing Python snippets in source files
License:        MIT
Group:          Development/Languages/Python
URL:            http://nedbatchelder.com/code/cog
Source:         https://files.pythonhosted.org/packages/source/c/cogapp/cogapp-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Cog is a file generation tool. It lets you use pieces of Python code
as generators in your source files to generate whatever text you
need.

%prep
%autosetup -p1 -n cogapp-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
mv %{buildroot}%{_bindir}/cog.py %{buildroot}%{_bindir}/cog
%python_clone -a %{buildroot}%{_bindir}/cog

%check
# reverse -q from addopts in setup.cfg
%pytest -v

%post
%python_install_alternative cog

%postun
%python_uninstall_alternative cog

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%python_alternative %{_bindir}/cog
%{python_sitelib}/cogapp
%{python_sitelib}/cogapp-%{version}*-info

%changelog
* Mon May 29 2023 Daniel Garcia <daniel.garcia@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
- Use pyproject to build the package
* Tue Sep 27 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove not needed patch in prep section
- Change preun to postun to run python_uninstall_alternatives to remove rpmlint
  errors
* Mon Sep 26 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.3.0:
  Added the --check option to check whether files would change if run again, for use in continuous integration scenarios.
- Update to 3.2.0:
  Added the -P option to use print() instead of cog.outl() for code output.
- Update to 3.1.0:
  * Fix a problem with Python 3.8.10 and 3.9.5 that require absolute paths in sys.path
    https://github.com/nedbat/cog/issues/16
    Python 3.9 and 3.10 are supported.
* Fri May  7 2021 Ben Greiner <code@bnavigator.de>
- always use absoulte import paths for -I parameter: mitigate
  failure due to bpo-43105 fix.
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.0:
  * Use pytest for testing
  * Many many changes in git but no readable changelog
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Apr 14 2017 toddrme2178@gmail.com
- Initial version
